pub struct WlDataDeviceManager { /* private fields */ }Expand description
A wl_data_device_manager object.
See the documentation of the module for the interface description.
Implementations
Sourceimpl WlDataDeviceManager
impl WlDataDeviceManager
Sourcepub fn set_handler(&self, handler: impl WlDataDeviceManagerHandler)
pub fn set_handler(&self, handler: impl WlDataDeviceManagerHandler)
Sets a new handler.
Sourcepub fn set_boxed_handler(&self, handler: Box<dyn WlDataDeviceManagerHandler>)
pub fn set_boxed_handler(&self, handler: Box<dyn WlDataDeviceManagerHandler>)
Sets a new, already boxed handler.
Sourceimpl WlDataDeviceManager
impl WlDataDeviceManager
Sourcepub const MSG__CREATE_DATA_SOURCE__SINCE: u32 = 1
pub const MSG__CREATE_DATA_SOURCE__SINCE: u32 = 1
Since when the create_data_source message is available.
Sourcepub const MSG__GET_DATA_DEVICE__SINCE: u32 = 1
pub const MSG__GET_DATA_DEVICE__SINCE: u32 = 1
Since when the get_data_device message is available.
Sourcepub const MSG__RELEASE__SINCE: u32 = 4
pub const MSG__RELEASE__SINCE: u32 = 4
Since when the release message is available.
Sourcepub fn try_send_create_data_source(
&self,
id: &Rc<WlDataSource>,
) -> Result<(), ObjectError>
pub fn try_send_create_data_source( &self, id: &Rc<WlDataSource>, ) -> Result<(), ObjectError>
Sourcepub fn send_create_data_source(&self, id: &Rc<WlDataSource>)
pub fn send_create_data_source(&self, id: &Rc<WlDataSource>)
Sourcepub fn new_try_send_create_data_source(
&self,
) -> Result<Rc<WlDataSource>, ObjectError>
pub fn new_try_send_create_data_source( &self, ) -> Result<Rc<WlDataSource>, ObjectError>
create a new data source
Create a new data source.
Sourcepub fn new_send_create_data_source(&self) -> Rc<WlDataSource>
pub fn new_send_create_data_source(&self) -> Rc<WlDataSource>
create a new data source
Create a new data source.
Sourcepub fn try_send_get_data_device(
&self,
id: &Rc<WlDataDevice>,
seat: &Rc<WlSeat>,
) -> Result<(), ObjectError>
pub fn try_send_get_data_device( &self, id: &Rc<WlDataDevice>, seat: &Rc<WlSeat>, ) -> Result<(), ObjectError>
create a new data device
Create a new data device for a given seat.
Arguments
id: data device to createseat: seat associated with the data device
Sourcepub fn send_get_data_device(&self, id: &Rc<WlDataDevice>, seat: &Rc<WlSeat>)
pub fn send_get_data_device(&self, id: &Rc<WlDataDevice>, seat: &Rc<WlSeat>)
create a new data device
Create a new data device for a given seat.
Arguments
id: data device to createseat: seat associated with the data device
Sourcepub fn new_try_send_get_data_device(
&self,
seat: &Rc<WlSeat>,
) -> Result<Rc<WlDataDevice>, ObjectError>
pub fn new_try_send_get_data_device( &self, seat: &Rc<WlSeat>, ) -> Result<Rc<WlDataDevice>, ObjectError>
create a new data device
Create a new data device for a given seat.
Arguments
seat: seat associated with the data device
Sourcepub fn new_send_get_data_device(&self, seat: &Rc<WlSeat>) -> Rc<WlDataDevice>
pub fn new_send_get_data_device(&self, seat: &Rc<WlSeat>) -> Rc<WlDataDevice>
create a new data device
Create a new data device for a given seat.
Arguments
seat: seat associated with the data device
Sourcepub fn try_send_release(&self) -> Result<(), ObjectError>
pub fn try_send_release(&self) -> Result<(), ObjectError>
destroy wl_data_device_manager
This request destroys the wl_data_device_manager. This has no effect on any other objects.
Sourcepub fn send_release(&self)
pub fn send_release(&self)
destroy wl_data_device_manager
This request destroys the wl_data_device_manager. This has no effect on any other objects.
Sourceimpl WlDataDeviceManager
impl WlDataDeviceManager
Sourcepub const ENM__DND_ACTION_NONE__SINCE: u32 = 1
pub const ENM__DND_ACTION_NONE__SINCE: u32 = 1
Since when the dnd_action.none enum variant is available.
Sourcepub const ENM__DND_ACTION_COPY__SINCE: u32 = 1
pub const ENM__DND_ACTION_COPY__SINCE: u32 = 1
Since when the dnd_action.copy enum variant is available.
Sourcepub const ENM__DND_ACTION_MOVE__SINCE: u32 = 1
pub const ENM__DND_ACTION_MOVE__SINCE: u32 = 1
Since when the dnd_action.move enum variant is available.
Sourcepub const ENM__DND_ACTION_ASK__SINCE: u32 = 1
pub const ENM__DND_ACTION_ASK__SINCE: u32 = 1
Since when the dnd_action.ask enum variant is available.