pub struct WlShell { /* private fields */ }Expand description
A wl_shell object.
See the documentation of the module for the interface description.
Implementations
Sourceimpl WlShell
impl WlShell
Sourcepub fn set_handler(&self, handler: impl WlShellHandler)
pub fn set_handler(&self, handler: impl WlShellHandler)
Sets a new handler.
Sourcepub fn set_boxed_handler(&self, handler: Box<dyn WlShellHandler>)
pub fn set_boxed_handler(&self, handler: Box<dyn WlShellHandler>)
Sets a new, already boxed handler.
Sourceimpl WlShell
impl WlShell
Sourcepub const MSG__GET_SHELL_SURFACE__SINCE: u32 = 1
pub const MSG__GET_SHELL_SURFACE__SINCE: u32 = 1
Since when the get_shell_surface message is available.
Sourcepub fn try_send_get_shell_surface(
&self,
id: &Rc<WlShellSurface>,
surface: &Rc<WlSurface>,
) -> Result<(), ObjectError>
pub fn try_send_get_shell_surface( &self, id: &Rc<WlShellSurface>, surface: &Rc<WlSurface>, ) -> Result<(), ObjectError>
create a shell surface from a surface
Create a shell surface for an existing surface. This gives the wl_surface the role of a shell surface. If the wl_surface already has another role, it raises a protocol error.
Only one shell surface can be associated with a given surface.
Arguments
id: shell surface to createsurface: surface to be given the shell surface role
Sourcepub fn send_get_shell_surface(
&self,
id: &Rc<WlShellSurface>,
surface: &Rc<WlSurface>,
)
pub fn send_get_shell_surface( &self, id: &Rc<WlShellSurface>, surface: &Rc<WlSurface>, )
create a shell surface from a surface
Create a shell surface for an existing surface. This gives the wl_surface the role of a shell surface. If the wl_surface already has another role, it raises a protocol error.
Only one shell surface can be associated with a given surface.
Arguments
id: shell surface to createsurface: surface to be given the shell surface role
Sourcepub fn new_try_send_get_shell_surface(
&self,
surface: &Rc<WlSurface>,
) -> Result<Rc<WlShellSurface>, ObjectError>
pub fn new_try_send_get_shell_surface( &self, surface: &Rc<WlSurface>, ) -> Result<Rc<WlShellSurface>, ObjectError>
create a shell surface from a surface
Create a shell surface for an existing surface. This gives the wl_surface the role of a shell surface. If the wl_surface already has another role, it raises a protocol error.
Only one shell surface can be associated with a given surface.
Arguments
surface: surface to be given the shell surface role
Sourcepub fn new_send_get_shell_surface(
&self,
surface: &Rc<WlSurface>,
) -> Rc<WlShellSurface>
pub fn new_send_get_shell_surface( &self, surface: &Rc<WlSurface>, ) -> Rc<WlShellSurface>
create a shell surface from a surface
Create a shell surface for an existing surface. This gives the wl_surface the role of a shell surface. If the wl_surface already has another role, it raises a protocol error.
Only one shell surface can be associated with a given surface.
Arguments
surface: surface to be given the shell surface role